/* mat.h		msjohnson		*/
 *	different matrices (PAM250 etc) including one based on 110
 *	aligned 3D structures: STRMAT110
 *      computed according to:
 *		Johnson & Overington (1993) J. Mol. Biol. 233:716-738 
 *      see Johnson, Overington & Blundell (1993) J. Mol. Biol. 231:735-752.
 *          Overington, Johnson, Sali & Blundell (1990) Proc. Roy. Soc. London
 *	    ser. B, 241:146-152.
 *	    Sali & Overington (1994) Prot. Sci. 3:1582-1596.
 */

/*
## 
##  TRADITIONAL DISCLAIMER
##
##  Copyright 1988-1996 John Overington & Mark Johnson
##  
##  Permission to use, copy, modify, and distribute this data, software
##  and its documentation for academic purposes is hereby granted without fee,
##  provided that the above copyright notice appear in all copies and that
##  both that copyright notice and this permission notice appear in
##  supporting documentation, and that the name of John Overington or Mark
##  Johnson or our respective institutions
##  not be used in advertising or publicity pertaining to distribution of
##  the software without specific, written prior permission. We
##  makes no representations about the suitability of this software for any
##  purpose. It is provided "as is" without express or implied warranty.
##  
##  JOHN OVERINGTON  AND MARK JOHNSON DISCLAIM ALL WARRANTIES WITH REGARD TO
##  THIS SOFTWARE/DATA, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
##  FITNESS, IN NO EVENT SHALL OUR HOME INSTITUTIONS BE LIABLE FOR ANY SPECIAL,
##  INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
##  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
##  OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE
##  OR PERFORMANCE OF THIS SOFTWARE.
##  
##  Primary authors:
##  	Dr. John Overington
##      Pfizer Central Research
##  	Pfizer UK
##  	Sandwich, Kent, UK
##
##  	jpo@sandwich.pfizer.com
##
##	Dr. Mark Johnson
##	Turku Center for Biotechnology
##	University of Turku & Abo Akademi University
##	PO Box 123
##	FIN-20521 Turku, Finland
##
##	mark@hops.btk.utu.fi
##
## Please send any improvements, bug fixes, useful modifications, and comments
## to one of the addresses above
*/


#define MAT_VER	"[matrix version 11.0 (last update: 24-11-95)]"
#define MAX_MAT 15	/* Limit to matrices in mat10.h */
#define MAX_VAL 21	/* Limit to dimensions in mat10.h */

/*
 *	B -> D (2); Z -> E (3); X (unknown) -> 21 == 0's in matrix
 */

int ind[MAX_IND]={ 0, 2, 1, 2, 3, 4, 5, 6, 7,21, 8, 9,10, 
                  11,21,12,13,14,15,16,21,17,18,21,19, 3};

/*
values in matrices are in alphabetical order (with the exception of X):
	ACDEFGHIKLMNPQRSTVWYX

border of matrices: }, { 
*/

char m_names[MAX_MAT][MAX_CDE]=

{"STRMAT110", "DAYHOFF", "DOOLITTLE", "FITCH", "GRANTHAM",
"LEVIN", "MCLACHLAN", "MIYATA", "RAO", "RISLER", "GONNET",
"HENIKOFF", "JONES", "PAM120", "TEST MATRIX"};

/* m_100: scaled matrices; */


int mats[MAX_MAT][MAX_VAL][MAX_VAL] = { 
{ 
{65,10,43,45,37,45,38,38,44,38,42,42,45,43,38,46,44,46,30,35,0},
{10,100, 7,16,20,11,18,14,11,14,19,20, 0,17,24,14,14,11,19,17,0},
{43, 7,72,53,27,41,43,28,43,25,29,54,43,44,37,45,41,32,28,35,0},
{45,16,53,72,31,40,43,33,48,31,37,45,42,53,43,41,42,36,28,35,0},
{37,20,27,31,77,24,42,48,30,51,47,33,30,31,31,30,31,43,50,58,0},
{45,11,41,40,24,71,37,24,37,25,29,42,36,35,37,41,33,29,31,32,0},
{38,18,43,43,42,37,83,31,47,36,39,51,37,50,46,39,38,35,35,47,0},
{38,14,28,33,48,24,31,72,32,53,54,33,33,30,32,32,40,58,36,40,0},
{44,11,43,48,30,37,47,32,68,37,40,47,40,50,56,42,45,37,31,34,0},
{38,14,25,31,51,25,36,53,37,68,59,32,33,37,38,30,35,51,39,39,0},
{42,19,29,37,47,29,39,54,40,59,79,36,27,42,35,34,40,48,47,40,0},
{42,20,54,45,33,42,51,33,47,32,36,70,41,44,45,49,46,33,31,41,0},
{45, 0,43,42,30,36,37,33,40,33,27,41,77,37,37,42,40,35,25,32,0},
{43,17,44,53,31,35,50,30,50,37,42,44,37,74,47,41,41,37,28,31,0},
{38,24,37,43,31,37,46,32,56,38,35,45,37,47,76,42,42,35,37,36,0},
{46,14,45,41,30,41,39,32,42,30,34,49,42,41,42,66,52,34,27,36,0},
{44,14,41,42,31,33,38,40,45,35,40,46,40,41,42,52,68,42,23,34,0},
{46,11,32,36,43,29,35,58,37,51,48,33,35,37,35,34,42,68,30,36,0},
{30,19,28,28,50,31,35,36,31,39,47,31,25,28,37,27,23,30,91,52,0},
{35,17,35,35,58,32,47,40,34,39,40,41,32,31,36,36,34,36,52,78,0},
{  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0},
},{
{ 40, 24, 32, 32, 16, 36, 28, 28, 28, 24, 28, 32, 36, 32, 24, 36, 36, 32,  8, 20, 0},
{ 24, 80, 12, 12, 16, 20, 20, 24, 12,  8, 12, 16, 20, 12, 16, 32, 24, 24,  0, 32, 0},
{ 32, 12, 48, 44,  8, 36, 36, 24, 32, 16, 20, 40, 28, 40, 28, 32, 32, 24,  4, 16, 0},
{ 32, 12, 44, 48, 12, 32, 36, 24, 32, 20, 24, 36, 28, 40, 28, 32, 32, 24,  4, 16, 0},
{ 16, 16,  8, 12, 68, 12, 24, 36, 12, 40, 32, 16, 12, 12, 16, 20, 20, 28, 32, 60, 0},
{ 36, 20, 36, 32, 12, 52, 24, 20, 24, 16, 20, 32, 28, 28, 20, 36, 32, 28,  4, 12, 0},
{ 28, 20, 36, 36, 24, 24, 56, 24, 32, 24, 24, 40, 32, 44, 40, 28, 28, 24, 20, 32, 0},
{ 28, 24, 24, 24, 36, 20, 24, 52, 24, 40, 40, 24, 24, 24, 24, 28, 32, 48, 12, 28, 0},
{ 28, 12, 32, 32, 12, 24, 32, 24, 52, 20, 32, 36, 28, 36, 44, 32, 32, 24, 20, 16, 0},
{ 24,  8, 16, 20, 40, 16, 24, 40, 20, 56, 48, 20, 20, 24, 20, 20, 24, 40, 24, 28, 0},
{ 28, 12, 20, 24, 32, 20, 24, 40, 32, 48, 56, 24, 24, 28, 32, 24, 28, 40, 16, 24, 0},
{ 32, 16, 40, 36, 16, 32, 40, 24, 36, 20, 24, 40, 28, 36, 32, 36, 32, 24, 16, 24, 0},
{ 36, 20, 28, 28, 12, 28, 32, 24, 28, 20, 24, 28, 56, 32, 32, 36, 32, 28,  8, 12, 0},
{ 32, 12, 40, 40, 12, 28, 44, 24, 36, 24, 28, 36, 32, 48, 36, 28, 28, 24, 12, 16, 0},
{ 24, 16, 28, 28, 16, 20, 40, 24, 44, 20, 32, 32, 32, 36, 56, 32, 28, 24, 40, 16, 0},
{ 36, 32, 32, 32, 20, 36, 28, 28, 32, 20, 24, 36, 36, 28, 32, 40, 36, 28, 24, 20, 0},
{ 36, 24, 32, 32, 20, 32, 28, 32, 32, 24, 28, 32, 32, 28, 28, 36, 44, 32, 12, 20, 0},
{ 32, 24, 24, 24, 28, 28, 24, 48, 24, 40, 40, 24, 28, 24, 24, 28, 32, 48,  8, 24, 0},
{  8,  0,  4,  4, 32,  4, 20, 12, 20, 24, 16, 16,  8, 12, 40, 24, 12,  8,100, 32, 0},
{ 20, 32, 16, 16, 60, 12, 32, 28, 16, 28, 24, 24, 12, 16, 16, 20, 20, 24, 32, 72, 0},
{  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0},
},{
{100, 33, 67, 67, 33, 83, 33, 33, 50, 33, 33, 50, 83, 50, 33, 83, 83, 83, 33, 33, 0},
{ 33,100, 17,  0, 50, 50, 33, 33,  0, 33, 33, 33, 33, 17, 33, 67, 33, 33, 50, 50, 0},
{ 67, 17,100, 83, 17, 67, 50, 17, 50, 17,  0, 83, 33, 67, 33, 50, 33, 50,  0, 33, 0},
{ 67,  0, 83,100,  0, 67, 33, 17, 67, 17, 17, 50, 50, 67, 33, 50, 50, 67, 17, 17, 0},
{ 33, 50, 17,  0,100, 17, 33, 67,  0, 67, 33, 17, 33, 17, 17, 50, 17, 67, 50, 83, 0},
{ 83, 50, 67, 67, 17,100, 17, 33, 33, 33, 17, 50, 50, 33, 50, 83, 33, 67, 50, 33, 0},
{ 33, 33, 50, 33, 33, 17,100, 17, 50, 50, 17, 67, 50, 67, 67, 50, 33, 17, 17, 50, 0},
{ 33, 33, 17, 17, 67, 33, 17,100, 33, 83, 67, 33, 33, 17, 33, 33, 50, 83, 33, 50, 0},
{ 50,  0, 50, 67,  0, 33, 50, 33,100, 33, 33, 67, 33, 67, 83, 50, 67, 50, 17, 17, 0},
{ 33, 33, 17, 17, 67, 33, 50, 83, 33,100, 83, 17, 50, 33, 33, 33, 33, 83, 67, 50, 0},
{ 33, 33,  0, 17, 33, 17, 17, 67, 33, 83,100, 17, 33, 33, 33, 17, 50, 67, 50, 33, 0},
{ 50, 33, 83, 50, 17, 50, 67, 33, 67, 17, 17,100, 33, 50, 33, 83, 67, 33,  0, 50, 0},
{ 83, 33, 33, 50, 33, 50, 50, 33, 33, 50, 33, 33,100, 50, 50, 67, 67, 50, 33, 33, 0},
{ 50, 17, 67, 67, 17, 33, 67, 17, 67, 33, 33, 50, 50,100, 50, 50, 50, 33, 17, 33, 0},
{ 33, 33, 33, 33, 17, 50, 67, 33, 83, 33, 33, 33, 50, 50,100, 50, 50, 33, 33, 17, 0},
{ 83, 67, 50, 50, 50, 83, 50, 33, 50, 33, 17, 83, 67, 50, 50,100, 83, 33, 33, 50, 0},
{ 83, 33, 33, 50, 17, 33, 33, 50, 67, 33, 50, 67, 67, 50, 50, 83,100, 50, 17, 33, 0},
{ 83, 33, 50, 67, 67, 67, 17, 83, 50, 83, 67, 33, 50, 33, 33, 33, 50,100, 50, 50, 0},
{ 33, 50,  0, 17, 50, 50, 17, 33, 17, 67, 50,  0, 33, 17, 33, 33, 17, 50,100, 50, 0},
{ 33, 50, 33, 17, 83, 33, 50, 50, 17, 50, 33, 50, 33, 33, 17, 50, 33, 50, 50,100, 0},
{  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0},
},{
{100, 25, 50, 50, 25, 50, 25, 25, 25, 25, 25, 25, 50, 25, 25, 50, 50, 50, 25, 25, 0},
{ 25,100, 25,  0, 50, 50, 25, 25,  0, 25,  0, 25, 25,  0, 50, 50, 25, 25, 50, 50, 0},
{ 50, 25,100, 50, 25, 50, 50, 25, 25, 25,  0, 50, 25, 25, 25, 25, 25, 50,  0, 50, 0},
{ 50,  0, 50,100,  0, 50, 25, 25, 50, 25, 25, 25, 25, 50, 25, 25, 25, 50, 25, 25, 0},
{ 25, 50, 25,  0,100, 25, 25, 50,  0, 50, 25, 25, 25,  0, 25, 50, 25, 50, 25, 50, 0},
{ 50, 50, 50, 50, 25,100, 25, 25, 25, 25, 25, 25, 25, 25, 50, 50, 25, 50, 50, 25, 0},
{ 25, 25, 50, 25, 25, 25,100, 25, 25, 50,  0, 50, 50, 50, 50, 25, 25, 25,  0, 50, 0},
{ 25, 25, 25, 25, 50, 25, 25,100, 50, 50, 50, 50, 25, 25, 50, 50, 50, 50,  0, 25, 0},
{ 25,  0, 25, 50,  0, 25, 25, 50,100, 25, 50, 50, 25, 50, 50, 25, 50, 25, 25, 25, 0},
{ 25, 25, 25, 25, 50, 25, 50, 50, 25,100, 50, 25, 50, 50, 50, 50, 25, 50, 50, 25, 0},
{ 25,  0,  0, 25, 25, 25,  0, 50, 50, 50,100, 25, 25, 25, 50, 25, 50, 50, 25,  0, 0},
{ 25, 25, 50, 25, 25, 25, 50, 50, 50, 25, 25,100, 25, 25, 25, 50, 50, 25,  0, 50, 0},
{ 50, 25, 25, 25, 25, 25, 50, 25, 25, 50, 25, 25,100, 50, 50, 50, 50, 25, 25, 25, 0},
{ 25,  0, 25, 50,  0, 25, 50, 25, 50, 50, 25, 25, 50,100, 50, 25, 25, 25, 25, 25, 0},
{ 25, 50, 25, 25, 25, 50, 50, 50, 50, 50, 50, 25, 50, 50,100, 50, 50, 25, 50, 25, 0},
{ 50, 50, 25, 25, 50, 50, 25, 50, 25, 50, 25, 50, 50, 25, 50,100, 50, 25, 50, 50, 0},
{ 50, 25, 25, 25, 25, 25, 25, 50, 50, 25, 50, 50, 50, 25, 50, 50,100, 25, 25, 25, 0},
{ 50, 25, 50, 50, 50, 50, 25, 50, 25, 50, 50, 25, 25, 25, 25, 25, 25,100, 25, 25, 0},
{ 25, 50,  0, 25, 25, 50,  0,  0, 25, 50, 25,  0, 25, 25, 50, 50, 25, 25,100, 25, 0},
{ 25, 50, 50, 25, 50, 25, 50, 25, 25, 25,  0, 50, 25, 25, 25, 50, 25, 25, 25,100, 0},
},{
{100,  9, 41, 50, 45, 73, 59, 54, 50, 54, 59, 45, 86, 54, 45, 54, 73, 68, 32, 45, 0},
{  9,100, 27, 23,  4, 27, 18,  9,  4,  9,  9, 36, 23, 27, 18, 45, 32,  9,  0,  9, 0},
{ 41, 27,100, 77, 18, 54, 59, 23, 50, 18, 27, 86, 50, 68, 54, 68, 59, 27, 14, 27, 0},
{ 50, 23, 77,100, 36, 54, 82, 36, 73, 36, 41, 77, 54, 86, 73, 64, 68, 41, 27, 41, 0},
{ 45,  4, 18, 36,100, 27, 54, 86, 50, 86, 86, 27, 45, 45, 54, 27, 50, 77, 82, 86, 0},
{ 73, 27, 54, 54, 27,100, 54, 36, 41, 36, 41, 64, 77, 59, 41, 73, 73, 50, 14, 32, 0},
{ 59, 18, 59, 82, 54, 54,100, 54, 82, 54, 59, 68, 64, 86, 86, 59, 77, 59, 45, 59, 0},
{ 54,  9, 23, 36, 86, 36, 54,100, 50, 95, 95, 32, 54, 50, 54, 32, 59, 86, 68, 82, 0},
{ 50,  4, 50, 73, 50, 41, 82, 50,100, 50, 54, 54, 50, 73, 86, 41, 64, 54, 50, 59, 0},
{ 54,  9, 18, 36, 86, 36, 54, 95, 50,100, 91, 27, 54, 45, 50, 32, 54, 82, 68, 82, 0},
{ 59,  9, 27, 41, 86, 41, 59, 95, 54, 91,100, 32, 59, 50, 54, 36, 59, 86, 68, 82, 0},
{ 45, 36, 86, 77, 27, 64, 68, 32, 54, 27, 32,100, 54, 77, 59, 77, 68, 36, 18, 32, 0},
{ 86, 23, 50, 54, 45, 77, 64, 54, 50, 54, 59, 54,100, 64, 50, 64, 82, 68, 32, 50, 0},
{ 54, 27, 68, 86, 45, 59, 86, 50, 73, 45, 50, 77, 64,100, 77, 68, 77, 54, 41, 54, 0},
{ 45, 18, 54, 73, 54, 41, 86, 54, 86, 50, 54, 59, 50, 77,100, 50, 64, 54, 50, 64, 0},
{ 54, 45, 68, 64, 27, 73, 59, 32, 41, 32, 36, 77, 64, 68, 50,100, 73, 41, 18, 32, 0},
{ 73, 32, 59, 68, 50, 73, 77, 59, 64, 54, 59, 68, 82, 77, 64, 73,100, 68, 41, 54, 0},
{ 68,  9, 27, 41, 77, 50, 59, 86, 54, 82, 86, 36, 68, 54, 54, 41, 68,100, 59, 73, 0},
{ 32,  0, 14, 27, 82, 14, 45, 68, 50, 68, 68, 18, 32, 41, 50, 18, 41, 59,100, 82, 0},
{ 45,  9, 27, 41, 86, 32, 59, 82, 59, 82, 82, 32, 50, 54, 64, 32, 54, 73, 82,100, 0},
},{
{ 50, 25, 50, 75,  0, 25, 25,  0, 25,  0,  0, 25,  0, 50, 25, 25, 25,  0,  0,  0, 0},
{ 25, 75, 25, 25,  0, 25, 25, 25, 25, 25, 25, 25, 25, 25, 25, 25, 25, 25,  0,  0, 0},
{ 25, 25, 75, 50,  0, 25, 25,  0, 25,  0,  0, 50, 25, 25, 25, 25, 25,  0,  0,  0, 0},
{ 50, 25, 50, 75,  0, 25, 25,  0, 25,  0,  0, 25,  0, 50, 25, 25, 25,  0,  0,  0, 0},
{  0,  0,  0,  0, 75,  0,  0, 50,  0, 25, 25,  0,  0,  0,  0,  0,  0, 25, 25, 50, 0},
{ 25, 25, 25, 25,  0, 75, 25,  0, 25,  0,  0, 25, 25, 25, 25, 25, 25,  0,  0,  0, 0},
{ 25, 25, 25, 25,  0, 25, 75,  0, 25,  0,  0, 25, 25, 25, 25, 25, 25,  0,  0, 25, 0},
{ 25, 25,  0,  0, 50,  0,  0, 75,  0, 25, 25,  0,  0,  0,  0,  0, 25, 50, 25, 25, 0},
{ 25, 25, 25, 25,  0, 25, 25,  0, 75,  0,  0, 50, 25, 25, 50, 25, 25,  0,  0,  0, 0},
{ 25, 25,  0,  0, 25,  0,  0, 25,  0, 75, 75,  0,  0,  0,  0,  0, 25, 50, 25, 25, 0},
{ 25, 25,  0,  0, 25,  0,  0, 25,  0, 75, 75,  0,  0,  0,  0,  0, 25, 25, 25, 25, 0},
{ 25, 25, 50, 25,  0, 25, 25,  0, 50,  0,  0,100, 25, 50, 25, 25, 25,  0,  0,  0, 0},
{  0, 25, 25,  0,  0, 25, 25,  0, 25,  0,  0, 25,100, 25, 25, 25, 25,  0,  0,  0, 0},
{ 25, 25, 25, 50,  0, 25, 25,  0, 25,  0,  0, 50, 25, 75, 25, 25, 25,  0,  0,  0, 0},
{ 25, 25, 25, 25,  0, 25, 25,  0, 50,  0,  0, 25, 25, 25, 75, 25, 25,  0, 25,  0, 0},
{ 50, 25, 25, 25,  0, 25, 25,  0, 25,  0,  0, 25, 25, 25, 25, 75, 25,  0,  0,  0, 0},
{ 25, 25, 25, 25,  0, 25, 25, 25, 25, 25, 25, 25, 25, 25, 25, 25, 75, 25,  0,  0, 0},
{ 25, 25,  0,  0, 25,  0,  0, 50,  0, 50, 25,  0,  0,  0,  0,  0, 25, 75, 25, 25, 0},
{  0,  0,  0,  0, 25,  0,  0, 25,  0, 25, 25,  0,  0,  0, 25,  0,  0, 25, 75, 25, 0},
{  0,  0,  0,  0, 50,  0, 25, 25,  0, 25, 25,  0,  0,  0,  0,  0,  0, 25, 25, 75, 0},
},{
{ 89, 11, 33, 44, 11, 33, 33, 22, 33, 22, 33, 33, 44, 33, 22, 44, 33, 33, 11, 11, 0},
{ 11,100, 11,  0,  0, 11, 33, 11,  0,  0, 33, 11,  0,  0, 11, 22, 22, 11, 22, 11, 0},
{ 33, 11, 89, 56, 11, 33, 44, 11, 33, 11, 22, 56, 33, 44, 11, 33, 33, 11,  0, 11, 0},
{ 44,  0, 56, 89,  0, 33, 22, 11, 44, 11, 11, 44, 44, 56, 33, 44, 44, 22, 11, 22, 0},
{ 11,  0, 11,  0,100,  0, 44, 33,  0, 56, 56,  0, 11,  0, 11, 22, 11, 33, 67, 67, 0},
{ 33, 11, 33, 33,  0, 89, 22, 11, 33, 11, 11, 33, 33, 22, 33, 33, 22, 22, 11,  0, 0},
{ 33, 33, 44, 22, 44, 22, 89, 22, 44, 22, 33, 44, 33, 44, 56, 33, 44, 22, 33, 44, 0},
{ 22, 11, 11, 11, 33, 11, 22, 89, 11, 56, 56, 11, 11,  0, 11, 22, 33, 56, 33, 33, 0},
{ 33,  0, 33, 44,  0, 33, 44, 11, 89, 22, 11, 44, 33, 44, 56, 33, 33, 22, 11, 11, 0},
{ 22,  0, 11, 11, 56, 11, 22, 56, 22, 89, 67, 11, 11, 33, 22, 22, 33, 56, 33, 33, 0},
{ 33, 33, 22, 11, 56, 11, 33, 56, 11, 67, 89, 22, 11, 33, 11, 22, 33, 44, 11, 22, 0},
{ 33, 11, 56, 44,  0, 33, 44, 11, 44, 11, 22, 89, 11, 44, 33, 56, 33, 11,  0, 22, 0},
{ 44,  0, 33, 44, 11, 33, 33, 11, 33, 11, 11, 11, 89, 33, 33, 33, 33, 22,  0,  0, 0},
{ 33,  0, 44, 56,  0, 22, 44,  0, 44, 33, 33, 44, 33, 89, 56, 44, 33, 22, 22, 11, 0},
{ 22, 11, 11, 33, 11, 33, 56, 11, 56, 22, 11, 33, 33, 56, 89, 44, 33, 22, 33, 22, 0},
{ 44, 22, 33, 44, 22, 33, 33, 22, 33, 22, 22, 56, 33, 44, 44, 89, 56, 22, 33, 33, 0},
{ 33, 22, 33, 44, 11, 22, 44, 33, 33, 33, 33, 33, 33, 33, 33, 56, 89, 33, 22, 11, 0},
{ 33, 11, 11, 22, 33, 22, 22, 56, 22, 56, 44, 11, 22, 22, 22, 22, 33, 89, 22, 33, 0},
{ 11, 22,  0, 11, 67, 11, 33, 33, 11, 33, 11,  0,  0, 22, 33, 33, 22, 22,100, 67, 0},
{ 11, 11, 11, 22, 67,  0, 44, 33, 11, 33, 22, 22,  0, 11, 22, 33, 11, 33, 67,100, 0},
},{
{100, 72, 55, 53, 37, 82, 59, 47, 43, 47, 53, 67,100, 63, 43, 90, 82, 65, 18, 37, 0},
{ 72,100, 31, 37, 57, 57, 51, 69, 37, 69, 72, 45, 74, 51, 41, 65, 72, 84, 35, 53, 0},
{ 55, 31,100, 82, 18, 55, 67, 22, 61, 20, 27, 88, 53, 72, 55, 65, 61, 33,  4, 24, 0},
{ 53, 37, 82,100, 29, 47, 82, 33, 78, 31, 39, 84, 51, 84, 72, 61, 65, 43, 22, 37, 0},
{ 37, 57, 18, 29,100, 20, 49, 88, 45, 88, 84, 27, 39, 45, 53, 33, 49, 72, 78, 92, 0},
{ 82, 57, 55, 47, 20,100, 47, 29, 31, 29, 35, 63, 82, 51, 31, 84, 67, 47,  0, 22, 0},
{ 59, 51, 67, 82, 49, 47,100, 53, 84, 49, 57, 74, 59, 94, 84, 63, 74, 59, 39, 57, 0},
{ 47, 69, 22, 33, 88, 29, 53,100, 45, 98, 94, 35, 49, 51, 51, 43, 59, 84, 67, 84, 0},
{ 43, 37, 61, 78, 45, 31, 84, 45,100, 41, 49, 65, 43, 80, 92, 47, 59, 47, 39, 53, 0},
{ 47, 69, 20, 31, 88, 29, 49, 98, 41,100, 92, 31, 47, 47, 49, 41, 57, 82, 67, 82, 0},
{ 53, 72, 27, 39, 84, 35, 57, 94, 49, 92,100, 41, 55, 55, 55, 49, 65, 88, 63, 82, 0},
{ 67, 45, 88, 84, 27, 63, 74, 35, 65, 31, 41,100, 65, 80, 61, 74, 72, 47, 14, 33, 0},
{100, 74, 53, 51, 39, 82, 59, 49, 43, 47, 55, 65,100, 63, 43, 90, 84, 65, 20, 39, 0},
{ 63, 51, 72, 84, 45, 51, 94, 51, 80, 47, 55, 80, 63,100, 78, 69, 78, 59, 33, 51, 0},
{ 43, 41, 55, 72, 53, 31, 84, 51, 92, 49, 55, 61, 43, 78,100, 47, 61, 53, 47, 61, 0},
{ 90, 65, 65, 61, 33, 84, 63, 43, 47, 41, 49, 74, 90, 69, 47,100, 82, 59, 14, 35, 0},
{ 82, 72, 61, 65, 49, 67, 74, 59, 59, 57, 65, 72, 84, 78, 61, 82,100, 72, 31, 53, 0},
{ 65, 84, 33, 43, 72, 47, 59, 84, 47, 82, 88, 47, 65, 59, 53, 59, 72,100, 51, 70, 0},
{ 18, 35,  4, 22, 78,  0, 39, 67, 39, 67, 63, 14, 20, 33, 47, 14, 31, 51,100, 80, 0},
{ 37, 53, 24, 37, 92, 22, 57, 84, 53, 82, 82, 33, 39, 51, 61, 35, 53, 70, 80,100, 0},
},{
{100, 64, 50, 57, 57, 43, 64, 50, 57, 64, 64, 50, 28, 64, 43, 57, 57, 50, 64, 50, 0},
{ 64,100, 43, 50, 57, 43, 57, 43, 50, 64, 57, 50, 36, 57, 43, 57, 57, 43, 64, 57, 0},
{ 50, 43,100, 64, 14, 50, 50,  7, 64, 28, 21, 64, 43, 64, 57, 57, 50,  7, 28, 36, 0},
{ 57, 50, 64,100, 28, 28, 64, 14, 64, 36, 43, 57, 21, 64, 50, 50, 43, 14, 36, 28, 0},
{ 57, 57, 14, 28,100, 36, 50, 71, 28, 64, 57, 28, 14, 36, 21, 43, 57, 64, 64, 57, 0},
{ 43, 43, 50, 28, 36,100, 36, 28, 36, 28, 14, 57, 64, 43, 36, 64, 57, 28, 43, 57, 0},
{ 64, 57, 50, 64, 50, 36,100, 43, 64, 57, 57, 57, 21, 64, 57, 57, 57, 50, 57, 50, 0},
{ 50, 43,  7, 14, 71, 28, 43,100, 14, 57, 50, 21,  7, 28, 14, 43, 57, 71, 64, 57, 0},
{ 57, 50, 64, 64, 28, 36, 64, 14,100, 36, 43, 64, 28, 71, 64, 57, 50, 21, 36, 36, 0},
{ 64, 64, 28, 36, 64, 28, 57, 57, 36,100, 64, 36, 14, 50, 28, 43, 50, 57, 64, 50, 0},
{ 64, 57, 21, 43, 57, 14, 57, 50, 43, 64,100, 28,  0, 50, 28, 36, 43, 50, 57, 43, 0},
{ 50, 50, 64, 57, 28, 57, 57, 21, 64, 36, 28,100, 50, 64, 57, 64, 57, 21, 43, 43, 0},
{ 28, 36, 43, 21, 14, 64, 21,  7, 28, 14,  0, 50,100, 36, 28, 57, 43,  7, 28, 43, 0},
{ 64, 57, 64, 64, 36, 43, 64, 28, 71, 50, 50, 64, 36,100, 57, 57, 57, 28, 50, 43, 0},
{ 43, 43, 57, 50, 21, 36, 57, 14, 64, 28, 28, 57, 28, 57,100, 50, 50, 21, 36, 36, 0},
{ 57, 57, 57, 50, 43, 64, 57, 43, 57, 43, 36, 64, 57, 57, 50,100, 64, 43, 57, 64, 0},
{ 57, 57, 50, 43, 57, 57, 57, 57, 50, 50, 43, 57, 43, 57, 50, 64,100, 57, 64, 64, 0},
{ 50, 43,  7, 14, 64, 28, 50, 71, 21, 57, 50, 21,  7, 28, 21, 43, 57,100, 64, 57, 0},
{ 64, 64, 28, 36, 64, 43, 57, 64, 36, 64, 57, 43, 28, 50, 36, 57, 64, 64,100, 64, 0},
{ 50, 57, 36, 28, 57, 57, 50, 57, 36, 50, 43, 43, 43, 43, 36, 64, 64, 57, 64,100, 0},
},{
{100,  8, 50, 88, 60, 60, 30, 88, 80, 78, 70, 78, 40, 90, 82, 95, 92, 95, 22, 50, 0},
{  8,100,  2,  8,  5,  2,  0,  5,  5,  8,  5,  5,  0, 10,  8, 12, 10, 10,  0, 18, 0},
{ 50,  2,100, 70, 38, 35, 12, 45, 48, 40, 32, 65, 15, 60, 42, 62, 45, 45, 10, 35, 0},
{ 88,  8, 70,100, 60, 52, 30, 82, 80, 68, 60, 80, 42, 98, 92, 90, 85, 85, 20, 50, 0},
{ 60,  5, 38, 60,100, 35, 18, 70, 48, 70, 40, 55, 18, 62, 55, 58, 52, 65, 22, 95, 0},
{ 60,  2, 35, 52, 35,100, 15, 45, 42, 40, 35, 50, 15, 50, 48, 62, 50, 48, 12, 40, 0},
{ 30,  0, 12, 30, 18, 15,100, 25, 20, 22, 15, 38,  5, 32, 35, 35, 22, 28,  2, 25, 0},
{ 88,  5, 45, 82, 70, 45, 25,100, 70, 98, 68, 68, 30, 80, 80, 85, 85,100, 28, 55, 0},
{ 80,  5, 48, 80, 48, 42, 20, 70,100, 62, 55, 70, 28, 88, 98, 80, 75, 75, 18, 58, 0},
{ 78,  8, 40, 68, 70, 40, 22, 98, 62,100, 90, 65, 25, 72, 75, 78, 75, 95, 25, 58, 0},
{ 70,  5, 32, 60, 40, 35, 15, 68, 55, 90,100, 45, 15, 75, 72, 60, 65, 65, 12, 40, 0},
{ 78,  5, 65, 80, 55, 50, 38, 68, 70, 65, 45,100, 20, 85, 75, 92, 72, 72, 18, 42, 0},
{ 40,  0, 15, 42, 18, 15,  5, 30, 28, 25, 15, 20,100, 30, 38, 38, 32, 30,  5, 15, 0},
{ 90, 10, 60, 98, 62, 50, 32, 80, 88, 72, 75, 85, 30,100, 95, 90, 88, 82, 20, 58, 0},
{ 82,  8, 42, 92, 55, 48, 35, 80, 98, 75, 72, 75, 38, 95,100, 95, 92, 82, 25, 65, 0},
{ 95, 12, 62, 90, 58, 62, 35, 85, 80, 78, 60, 92, 38, 90, 95,100, 98, 90, 25, 55, 0},
{ 92, 10, 45, 85, 52, 50, 22, 85, 75, 75, 65, 72, 32, 88, 92, 98,100, 85, 20, 52, 0},
{ 95, 10, 45, 85, 65, 48, 28,100, 75, 95, 65, 72, 30, 82, 82, 90, 85,100, 28, 52, 0},
{ 22,  0, 10, 20, 22, 12,  2, 28, 18, 25, 12, 18,  5, 20, 25, 25, 20, 28,100, 30, 0},
{ 50, 18, 35, 50, 95, 40, 25, 55, 58, 58, 40, 42, 15, 58, 65, 55, 52, 52, 30,100, 0},
},{
{ 39, 29, 25, 27, 15, 29, 23, 23, 25, 21, 23, 25, 28, 26, 24, 32, 30, 27,  8, 15, 0},
{ 29, 86, 10, 11, 23, 16, 20, 21, 12, 19, 22, 18, 11, 14, 15, 27, 24, 27, 22, 24, 0},
{ 25, 10, 51, 41,  4, 27, 29,  7, 29,  6, 11, 38, 23, 31, 25, 29, 27, 12,  0, 12, 0},
{ 27, 11, 41, 45,  7, 23, 29, 13, 33, 12, 16, 31, 24, 36, 29, 28, 26, 17,  5, 13, 0},
{ 15, 23,  4,  7, 63,  0, 26, 32, 10, 37, 35, 11,  7, 13, 10, 12, 15, 27, 45, 53, 0},
{ 29, 16, 27, 23,  0, 61, 20,  4, 21,  4,  9, 29, 18, 22, 22, 29, 21, 10,  6,  6, 0},
{ 23, 20, 29, 29, 26, 20, 58, 15, 30, 17, 20, 33, 21, 33, 30, 26, 25, 16, 23, 38, 0},
{ 23, 21,  7, 13, 32,  4, 15, 47, 16, 41, 40, 12, 13, 17, 14, 18, 24, 43, 18, 23, 0},
{ 25, 12, 29, 33, 10, 21, 30, 16, 43, 16, 20, 31, 24, 34, 41, 27, 27, 18,  9, 16, 0},
{ 21, 19,  6, 12, 37,  4, 17, 41, 16, 47, 41, 11, 15, 18, 15, 16, 20, 36, 23, 27, 0},
{ 23, 22, 11, 16, 35,  9, 20, 40, 20, 41, 49, 15, 14, 22, 18, 20, 24, 35, 22, 26, 0},
{ 25, 18, 38, 31, 11, 29, 33, 12, 31, 11, 15, 46, 22, 30, 28, 31, 29, 15,  8, 20, 0},
{ 28, 11, 23, 24,  7, 18, 21, 13, 24, 15, 14, 22, 66, 26, 22, 29, 27, 18,  1, 11, 0},
{ 26, 14, 31, 36, 13, 22, 33, 17, 34, 18, 22, 30, 26, 41, 34, 28, 27, 19, 13, 18, 0},
{ 24, 15, 25, 29, 10, 22, 30, 14, 41, 15, 18, 28, 22, 34, 51, 26, 26, 16, 18, 18, 0},
{ 32, 27, 29, 28, 12, 29, 26, 18, 27, 16, 20, 31, 29, 28, 26, 38, 34, 22, 10, 17, 0},
{ 30, 24, 27, 26, 15, 21, 25, 24, 27, 20, 24, 29, 27, 27, 26, 34, 40, 27,  9, 17, 0},
{ 27, 27, 12, 17, 27, 10, 16, 43, 18, 36, 35, 15, 18, 19, 16, 22, 27, 44, 13, 21, 0},
{  8, 22,  0,  5, 45,  6, 23, 18,  9, 23, 22,  8,  1, 13, 18, 10,  9, 13,100, 48, 0},
{ 15, 24, 12, 13, 53,  6, 38, 23, 16, 27, 26, 20, 11, 18, 18, 17, 17, 21, 48, 67, 0},
},{ /*henikoff*/
{ 53, 27, 13, 20, 13, 27, 13, 20, 20, 20, 20, 13, 20, 20, 20, 33, 27, 27,  7, 13, 0},
{ 27, 87,  7,  0, 13,  7,  7, 20,  7, 20, 20,  7,  7,  7,  7, 20, 20, 20, 13, 13, 0},
{ 13,  7, 67, 40,  7, 20, 20,  7, 20,  0,  7, 33, 20, 27, 13, 27, 20,  7,  0,  7, 0},
{ 20,  0, 40, 60,  7, 13, 27,  7, 33,  7, 13, 27, 20, 40, 27, 27, 20, 13,  7, 13, 0},
{ 13, 13,  7,  7, 67,  7, 20, 27,  7, 27, 27,  7,  0,  7,  7, 13, 13, 20, 33, 47, 0},
{ 27,  7, 20, 13,  7, 67, 13,  0, 13,  0,  7, 27, 13, 13, 13, 27, 13,  7, 13,  7, 0},
{ 13,  7, 20, 27, 20, 13, 80,  7, 20,  7, 13, 33, 13, 27, 27, 20, 13,  7, 13, 40, 0},
{ 20, 20,  7,  7, 27,  0,  7, 53,  7, 40, 33,  7,  7,  7,  7, 13, 20, 47,  7, 20, 0},
{ 20,  7, 20, 33,  7, 13, 20,  7, 60, 13, 20, 27, 20, 33, 40, 27, 20, 13,  7, 13, 0},
{ 20, 20,  0,  7, 27,  0,  7, 40, 13, 53, 40,  7,  7, 13, 13, 13, 20, 33, 13, 20, 0},
{ 20, 20,  7, 13, 27,  7, 13, 33, 20, 40, 60, 13, 13, 27, 20, 20, 20, 33, 20, 20, 0},
{ 13,  7, 33, 27,  7, 27, 33,  7, 27,  7, 13, 67, 13, 27, 27, 33, 27,  7,  0, 13, 0},
{ 20,  7, 20, 20,  0, 13, 13,  7, 20,  7, 13, 13, 73, 20, 13, 20, 20, 13,  0,  7, 0},
{ 20,  7, 27, 40,  7, 13, 27,  7, 33, 13, 27, 27, 20, 60, 33, 27, 20, 13, 13, 20, 0},
{ 20,  7, 13, 27,  7, 13, 27,  7, 40, 13, 20, 27, 13, 33, 60, 20, 20,  7,  7, 13, 0},
{ 33, 20, 27, 27, 13, 27, 20, 13, 27, 13, 20, 33, 20, 27, 20, 53, 33, 13,  7, 13, 0},
{ 27, 20, 20, 20, 13, 13, 13, 20, 20, 20, 20, 27, 20, 20, 20, 33, 60, 27, 13, 13, 0},
{ 27, 20,  7, 13, 20,  7,  7, 47, 13, 33, 33,  7, 13, 13,  7, 13, 27, 53,  7, 20, 0},
{  7, 13,  0,  7, 33, 13, 13,  7,  7, 13, 20,  0,  0, 13,  7,  7, 13,  7,100, 40, 0},
{ 13, 13,  7, 13, 47,  7, 40, 20, 13, 20, 20, 13,  7, 20, 13, 13, 13, 20, 40, 73, 0},
},{/*jones*/
{ 35, 20, 25, 20, 10, 30, 15, 25, 20, 20, 20, 25, 30, 20, 20, 30, 35, 30,  5, 10, 0},
{ 20, 80, 10,  5, 25, 20, 25, 15, 10, 10, 15, 20, 15, 10, 20, 30, 20, 15, 30, 35, 0},
{ 25, 10, 50, 45,  0, 30, 25, 10, 25,  5, 10, 35, 15, 30, 20, 25, 20, 15,  0, 15, 0},
{ 20,  5, 45, 50,  0, 25, 25, 10, 30,  5, 10, 30, 15, 35, 25, 20, 20, 15,  0,  5, 0},
{ 10, 25,  0,  0, 65,  0, 25, 25,  0, 35, 25, 10, 10,  5,  5, 15, 15, 25, 20, 50, 0},
{ 30, 20, 30, 25,  0, 50, 15, 10, 20,  5, 10, 25, 20, 20, 25, 30, 20, 15, 15,  5, 0},
{ 15, 25, 25, 25, 25, 15, 55, 10, 30, 15, 15, 30, 25, 35, 35, 20, 20, 10, 10, 45, 0},
{ 25, 15, 10, 10, 25, 10, 10, 45, 10, 35, 40, 15, 15, 10, 10, 20, 30, 45,  5, 15, 0},
{ 20, 10, 25, 30,  0, 20, 30, 10, 50, 10, 15, 30, 15, 35, 45, 20, 20, 10, 10, 10, 0},
{ 20, 10,  5,  5, 35,  5, 15, 35, 10, 50, 40, 10, 25, 15, 10, 15, 20, 35, 15, 20, 0},
{ 20, 15, 10, 10, 25, 10, 15, 40, 15, 40, 55, 15, 15, 15, 15, 20, 25, 35, 10, 15, 0},
{ 25, 20, 35, 30, 10, 25, 30, 15, 30, 10, 15, 40, 20, 25, 25, 30, 30, 15,  0, 20, 0},
{ 30, 15, 15, 15, 10, 20, 25, 15, 15, 25, 15, 20, 55, 25, 20, 30, 30, 20,  5, 10, 0},
{ 20, 10, 30, 35,  5, 20, 35, 10, 35, 15, 15, 25, 25, 50, 35, 20, 20, 10, 10, 15, 0},
{ 20, 20, 20, 25,  5, 25, 35, 10, 45, 10, 15, 25, 20, 35, 50, 20, 20, 10, 25, 15, 0},
{ 30, 30, 25, 20, 15, 30, 20, 20, 20, 15, 20, 30, 30, 20, 20, 35, 30, 20, 10, 20, 0},
{ 35, 20, 20, 20, 15, 20, 20, 30, 20, 20, 25, 30, 30, 20, 20, 30, 35, 25,  5, 10, 0},
{ 30, 15, 15, 15, 25, 15, 10, 45, 10, 35, 35, 15, 20, 10, 10, 20, 25, 45, 10, 10, 0},
{  5, 30,  0,  0, 20, 15, 10,  5, 10, 15, 10,  0,  5, 10, 25, 10,  5, 10,100, 25, 0},
{ 10, 35, 15,  5, 50,  5, 45, 15, 10, 20, 15, 20, 10, 15, 15, 20, 10, 10, 25, 70, 0},
},{/*120pam*/
{ 55, 25, 40, 40, 20, 45, 25, 35, 30, 25, 30, 35, 45, 35, 25, 45, 45, 40,  5, 20, 0},
{ 25, 85,  5,  5, 10, 20, 20, 25,  5,  5, 10, 15, 20,  5, 20, 40, 25, 25,  0, 35, 0},
{ 40,  5, 65, 55,  5, 40, 40, 25, 35, 15, 20, 50, 25, 45, 25, 40, 35, 25,  0, 15, 0},
{ 40,  5, 55, 65,  5, 35, 35, 25, 35, 20, 25, 45, 30, 50, 25, 35, 30, 25,  0, 15, 0},
{ 20, 10,  5,  5, 80, 15, 25, 40,  5, 40, 35, 20, 15, 10, 15, 25, 20, 25, 35, 60, 0},
{ 45, 20, 40, 35, 15, 65, 20, 20, 25, 15, 20, 40, 30, 25, 20, 45, 35, 30,  0, 10, 0},
{ 25, 20, 40, 35, 25, 20, 75, 20, 30, 25, 20, 50, 35, 55, 45, 30, 25, 25, 25, 35, 0},
{ 35, 25, 25, 25, 40, 20, 20, 70, 25, 45, 45, 30, 25, 25, 30, 30, 40, 55, 10, 30, 0},
{ 30,  5, 35, 35,  5, 25, 30, 25, 65, 20, 40, 45, 30, 40, 50, 35, 35, 20, 15, 15, 0},
{ 25,  5, 15, 20, 40, 15, 25, 45, 20, 65, 55, 20, 25, 30, 20, 20, 25, 45, 25, 30, 0},
{ 30, 10, 20, 25, 35, 20, 20, 45, 40, 55, 80, 25, 25, 35, 35, 30, 35, 45, 10, 20, 0},
{ 35, 15, 50, 45, 20, 40, 50, 30, 45, 20, 25, 60, 30, 40, 35, 45, 40, 25, 20, 30, 0},
{ 45, 20, 25, 30, 15, 30, 35, 25, 30, 25, 25, 30, 70, 40, 35, 45, 35, 30,  5, 10, 0},
{ 35,  5, 45, 50, 10, 25, 55, 25, 40, 30, 35, 40, 40, 70, 45, 30, 30, 25, 10, 15, 0},
{ 25, 20, 25, 25, 15, 20, 45, 30, 50, 20, 35, 35, 35, 45, 70, 35, 30, 25, 45, 15, 0},
{ 45, 40, 40, 35, 25, 45, 30, 30, 35, 20, 30, 45, 45, 30, 35, 55, 50, 30, 30, 25, 0},
{ 45, 25, 35, 30, 20, 35, 25, 40, 35, 25, 35, 40, 35, 30, 30, 50, 60, 40, 10, 25, 0},
{ 40, 25, 25, 25, 25, 30, 25, 55, 20, 45, 45, 25, 30, 25, 25, 30, 40, 65,  0, 25, 0},
{  5,  0,  0,  0, 35,  0, 25, 10, 15, 25, 10, 20,  5, 10, 45, 30, 10,  0,100, 30, 0},
{ 20, 35, 15, 15, 60, 10, 35, 30, 15, 30, 20, 30, 10, 15, 15, 25, 25, 25, 30, 80, 0},
},{
/*
ng-gp
*/
{ 20, 22, 14, 13, 14, 13, 14, 22, 13, 18, 26, 22, 13,  5,  9, 18,  5, 30, 19, 26, 0},
{ 22,  0,-25,-22,  7,-14,-18, -9, -5, -5,  7,-18, -5, -9,-14,-14,-10,  3,-33,-22, 0},
{ 14,-25, 28,  5, 19, 14, 13, 11,  9,  3,  3, 21,  9,  5, 18, 13, 18, 11, -2,  6, 0},
{ 13,-22,  5, 19,  3, 10, 18, 11, 21, 15,  1, 13,  5,  9, 26,  5, 22, 18,  7, 22, 0},
{ 14,  7, 19,  3, 14,  3,  1, 17, 11,  5, -3, -3,-22, -1,  7, 18, 11, -3, 12, 28, 0},
{ 13,-14, 14, 10,  3, 19, -3, 22,  1, -1, -6, 13, 14, 14,  5,  9,  7, 15, -1, -2, 0},
{ 14,-18, 13, 18,  1, -3, 30,  7, 17, -2,  6, 13,  5, 13, 13,  5,  5, 10,  1,  5, 0},
{ 22, -9, 11, 11, 17, 22,  7, 11, 11, 17, 28, 10, -1, -1,  3, -2,  5,  3, -3, 18, 0},
{ 13, -5,  9, 21, 11,  1, 17, 11, 15, 14,  1, 13, 13, 13, 28, 13, 13, 14, 15, 15, 0},
{ 18, -5,  3, 15,  5, -1, -2, 17, 14, 11, 20, -1,  9, 11, -6,  7,  6,  9,  1, -7, 0},
{ 26,  7,  3,  1, -3, -6,  6, 28,  1, 20, -3,  1,-14, -3,  3, 11, 14, 17,  9,  5, 0},
{ 22,-18, 21, 13, -3, 13, 13, 10, 13, -1,  1, 28,  5, 13, 18, 17,  9, 19, -2,  1, 0},
{ 13, -5,  9,  5,-22, 14,  5, -1, 13,  9,-14,  5, 26,  6, 14, 13, 14, 14,-14,  3, 0},
{  5, -9,  5,  9, -1, 14, 13, -1, 13, 11, -3, 13,  6, 19, 21, 14, 13, 18,  3,  7, 0},
{  9,-14, 18, 26,  7,  5, 13,  3, 28, -6,  3, 18, 14, 21, 22,  9, 22, 19, -7,-14, 0},
{ 18,-14, 13,  5, 18,  9,  5, -2, 13,  7, 11, 17, 13, 14,  9, 24, 17,  7, -9, 10, 0},
{  5,-10, 18, 22, 11,  7,  5,  5, 13,  6, 14,  9, 14, 13, 22, 17, 20, 26,-16, 14, 0},
{ 30,  3, 11, 18, -3, 15, 10,  3, 14,  9, 17, 19, 14, 18, 19,  7, 26,  7,  6, 26, 0},
{ 19,-33, -2,  7, 12, -1,  1, -3, 15,  1,  9, -2,-14,  3, -7, -9,-16,  6,  5,  9, 0},
{ 26,-22,  6, 22, 28, -2,  5, 18, 15, -7,  5,  1,  3,  7,-14, 10, 14, 26,  9, 18, 0},},};



/*
65 families 
{ 62, 27, 35, 38, 27, 38, 31, 31, 38, 27, 38, 35, 38, 38, 38, 42, 38, 38, 23, 27, 0},
{ 27,100,  0, 23, 27,  4, 12, 15, 19,  0,  8,  8,  0, 19, 27, 12, 12, 15, 12,  8, 0},
{ 35,  0, 73, 50, 12, 35, 42, 23, 31,  8, 19, 54, 38, 38, 31, 42, 38, 19, 12, 27, 0},
{ 38, 23, 50, 69, 12, 35, 31, 23, 46, 15, 27, 42, 38, 50, 46, 35, 42, 31, 12, 31, 0},
{ 27, 27, 12, 12, 81,  8, 35, 46, 23, 50, 38, 19, 15, 19, 19, 23, 27, 38, 54, 58, 0},
{ 38,  4, 35, 35,  8, 69, 27, 15, 27, 12, 23, 38, 35, 31, 31, 38, 27, 19, 19, 23, 0},
{ 31, 12, 42, 31, 35, 27, 88, 19, 42, 19, 35, 50, 23, 42, 42, 31, 27, 31, 31, 38, 0},
{ 31, 15, 23, 23, 46, 15, 19, 73, 23, 50, 50, 27, 19, 12, 19, 23, 31, 54, 31, 35, 0},
{ 38, 19, 31, 46, 23, 27, 42, 23, 69, 31, 38, 42, 38, 46, 58, 38, 38, 27, 27, 31, 0},
{ 27,  0,  8, 15, 50, 12, 19, 50, 31, 69, 58, 23, 27, 23, 23, 19, 23, 46, 38, 31, 0},
{ 38,  8, 19, 27, 38, 23, 35, 50, 38, 58, 81, 31, 15, 46, 15, 15, 31, 42, 35, 35, 0},
{ 35,  8, 54, 42, 19, 38, 50, 27, 42, 23, 31, 69, 27, 38, 35, 46, 42, 15, 12, 35, 0},
{ 38,  0, 38, 38, 15, 35, 23, 19, 38, 27, 15, 27, 81, 31, 35, 35, 35, 19, 19, 12, 0},
{ 38, 19, 38, 50, 19, 31, 42, 12, 46, 23, 46, 38, 31, 73, 50, 38, 38, 31, 15, 27, 0},
{ 38, 27, 31, 46, 19, 31, 42, 19, 58, 23, 15, 35, 35, 50, 77, 38, 38, 27, 31, 35, 0},
{ 42, 12, 42, 35, 23, 38, 31, 23, 38, 19, 15, 46, 35, 38, 38, 62, 50, 27, 12, 31, 0},
{ 38, 12, 38, 42, 27, 27, 27, 31, 38, 23, 31, 42, 35, 38, 38, 50, 65, 35, 15, 31, 0},
{ 38, 15, 19, 31, 38, 19, 31, 54, 27, 46, 42, 15, 19, 31, 27, 27, 35, 65, 15, 35, 0},
{ 23, 12, 12, 12, 54, 19, 31, 31, 27, 38, 35, 12, 19, 15, 31, 12, 15, 15, 96, 54, 0},
{ 27,  8, 27, 31, 58, 23, 38, 35, 31, 31, 35, 35, 12, 27, 35, 31, 31, 35, 54, 81, 0},
*/
